@@ -25,9 +25,9 @@ use walkdir::WalkDir;
 /// Inspect Safe Network local testnet logs
 #[structopt(global_settings(&[ColoredHelp]))]
 struct CmdArgs {
-    /// subcommands
+    /// sub cmds
     #[structopt(subcommand)]
-    pub cmd: Option<SubCommands>,
+    pub cmd: Option<SubCmds>,
     /// Path to the testnet logs folder, e.g. ~/.safe/node/local-test-network
     pub logs_path: PathBuf,
     /// Show stats per node? (this is slower)
@@ -36,20 +36,20 @@ struct CmdArgs {
 }
 
 #[derive(StructOpt, Debug)]
-enum SubCommands {
-    /// Generate a report of commands and corresponding sub-commands
-    // TODO: make the cmd-id optional, to report all commands
-    Commands {
-        /// ID of the command to obtain a report for, e.g. 924678512
+enum SubCmds {
+    /// Generate a report of cmds and corresponding sub-cmds
+    // TODO: make the cmd-id optional, to report all cmds
+    Cmds {
+        /// ID of the cmd to obtain a report for, e.g. 924678512
         cmd_id: String,
     },
-    /// Generate a report of commands dispatched to process incoming messages
-    // TODO: make the msg-id optional, to report all messages
-    Messages {
-        /// ID of the message to obtain a report for, e.g. c971..cfb5
+    /// Generate a report of cmds dispatched to process incoming msgs
+    // TODO: make the msg-id optional, to report all msgs
+    Msgs {
+        /// ID of the msg to obtain a report for, e.g. c971..cfb5
         msg_id: String,
     },
-    /// Generate a report of commands dispatched, and which were started but not completed
+    /// Generate a report of cmds dispatched, and which were started but not completed
     IncompleteCmds,
 }
 
@@ -60,16 +60,16 @@ fn main() -> Result<()> {
     println!();
     if let Some(cmd) = args.cmd {
         match cmd {
-            SubCommands::Commands { cmd_id } => {
+            SubCmds::Cmds { cmd_id } => {
                 if report.is_empty() {
-                    println!("** No commands were found for cmd id {} **", cmd_id);
+                    println!("** No cmds were found for cmd id {} **", cmd_id);
                 } else {
                     println!(
-                        "*** REPORT: The following commands were found for cmd id {} ***",
+                        "*** REPORT: The following cmds were found for cmd id {} ***",
                         cmd_id
                     );
                     for (cmd_id, log_entries) in report.iter() {
-                        println!("==> Log entries for sub-command {}:", cmd_id);
+                        println!("==> Log entries for sub-cmd {}:", cmd_id);
                         for log_entry in log_entries.iter() {
                             println!("{}", log_entry);
                         }
@@ -77,16 +77,16 @@ fn main() -> Result<()> {
                     }
                 }
             }
-            SubCommands::Messages { msg_id } => {
+            SubCmds::Msgs { msg_id } => {
                 if report.is_empty() {
-                    println!("** No commands were found for msg id {} **", msg_id);
+                    println!("** No cmds were found for msg id {} **", msg_id);
                 } else {
                     println!(
-                        "*** REPORT: The following commands were found for msg id {} ***",
+                        "*** REPORT: The following cmds were found for msg id {} ***",
                         msg_id
                     );
                     for (cmd_id, log_entries) in report.iter() {
-                        println!("==> Log entries for sub-command {}:", cmd_id);
+                        println!("==> Log entries for sub-cmd {}:", cmd_id);
                         for log_entry in log_entries.iter() {
                             println!("{}", log_entry);
                         }
@@ -94,13 +94,13 @@ fn main() -> Result<()> {
                     }
                 }
             }
-            SubCommands::IncompleteCmds => {
+            SubCmds::IncompleteCmds => {
                 if report.is_empty() {
                     println!("** No errors detected in any of the logs scanned! **");
                 } else {
                     println!("*** REPORT: The following issues were detected ***");
                     for (logfile, log_entries) in report.iter() {
-                        println!("Commands not completed in log {}:", logfile);
+                        println!("Cmds not completed in log {}:", logfile);
                         for log_entry in log_entries.iter() {
                             println!("{}", log_entry);
                         }
@@ -113,54 +113,54 @@ fn main() -> Result<()> {
     Ok(())
 }
 
-// A command/subcommand id e.g. "963111461", "963111461.0"
+// A cmd/sub-cmd id e.g. "963111461", "963111461.0"
 type CmdId = String;
 // Entire log entry as read from log files
 type LogEntry = String;
-//  A message id, e.g. "68fe..b776"
+//  A msg id, e.g. "68fe..b776"
 type MsgId = String;
 //  A nodes id, as oer log folder, eg sn-node-14
 type NodeId = String;
 
 #[derive(Default, Clone)]
-// Tuple with log filepath, and the list of sommands/sub-commands and corresponding log entry.
-pub struct SubCommandsInfo {
+// Tuple with log filepath, and the list of cmds/sub-cmds and corresponding log entry.
+pub struct SubCmdsInfo {
     pub logfile: PathBuf,
-    pub cmds_logs: BTreeMap<CmdId, LogEntry>,
+    pub cmd_logs: BTreeMap<CmdId, LogEntry>,
 }
 
-impl SubCommandsInfo {
+impl SubCmdsInfo {
     pub fn new(logfile: PathBuf) -> Self {
         Self {
             logfile,
-            cmds_logs: BTreeMap::default(),
+            cmd_logs: BTreeMap::default(),
         }
     }
 
     pub fn insert(&mut self, cmd_id: CmdId, log_entry: LogEntry) {
-        self.cmds_logs.insert(cmd_id, log_entry);
+        self.cmd_logs.insert(cmd_id, log_entry);
     }
 }
 
-// Container for all info per each command root id
-type CommandsInfoList = BTreeMap<CmdId, SubCommandsInfo>;
+// Container for all info per each cmd root id
+type CmdsInfoList = BTreeMap<CmdId, SubCmdsInfo>;
 
 #[derive(Default, Clone)]
 pub struct ScannedInfo {
     // markers per node node
-    pub by_node: BTreeMap<NodeId, BTreeMap<LogMarker, CommandsInfoList>>,
+    pub by_node: BTreeMap<NodeId, BTreeMap<LogMarker, CmdsInfoList>>,
     // msgs handled per node
     pub msgs_per_node: BTreeMap<NodeId, Vec<MsgId>>,
     // log marker to cmd info
-    pub by_marker: BTreeMap<LogMarker, CommandsInfoList>,
+    pub by_marker: BTreeMap<LogMarker, CmdsInfoList>,
     // msg id to cmd root ids (can be same msg id received many times)
     pub cmd_by_msg_id: BTreeMap<MsgId, Vec<CmdId>>,
-    // msg id tied to a command that it spawned
+    // msg id tied to a cmd that it spawned
     pub counts: BTreeMap<LogMarker, usize>,
 }
 
 /// Search the local-test-network log file and return count
-pub fn update_commands_info_for_markers(
+pub fn update_cmds_info_for_markers(
     path: &Path,
     stats_per_node: bool,
 ) -> Result<ScannedInfo, Error> {
@@ -185,7 +185,7 @@ pub fn update_commands_info_for_markers(
 
     let matcher = RegexMatcher::new_line_matcher(&pattern)?;
     let cmd_id_regex = RegexMatcher::new_line_matcher(r".*cmd_id=([^\s-]*)")?;
-    let msg_id_regex = RegexMatcher::new_line_matcher(r".*MessageId\((.*)\)")?;
+    let msg_id_regex = RegexMatcher::new_line_matcher(r".*MsgId\((.*)\)")?;
 
     for path in paths {
         for result in WalkDir::new(path) {
@@ -224,12 +224,12 @@ pub fn update_commands_info_for_markers(
                             .entry(matched_marker.clone())
                             .or_insert_with(BTreeMap::default);
 
-                        let subcommand_info = marker_map
+                        let sub_cmd_info = marker_map
                             .entry(root_cmd_id.clone())
-                            .or_insert_with(|| SubCommandsInfo::new(path.clone()));
+                            .or_insert_with(|| SubCmdsInfo::new(path.clone()));
 
                         // track the entry
-                        subcommand_info.insert(cmd_id.clone(), line.to_string());
+                        sub_cmd_info.insert(cmd_id.clone(), line.to_string());
 
                         // Now per node
                         let mut node_file_path = dent.path().to_path_buf();
@@ -254,11 +254,11 @@ pub fn update_commands_info_for_markers(
                                 .or_insert_with(BTreeMap::default);
 
                             // nodes_markers_map.insert(root_cmd_id.clone(), value)
-                            let per_node_subcommand_info = nodes_markers_map
+                            let per_node_sub_cmd_info = nodes_markers_map
                                 .entry(root_cmd_id.clone())
-                                .or_insert_with(|| SubCommandsInfo::new(path.clone()));
+                                .or_insert_with(|| SubCmdsInfo::new(path.clone()));
 
-                            per_node_subcommand_info.insert(cmd_id.clone(), line.to_string());
+                            per_node_sub_cmd_info.insert(cmd_id.clone(), line.to_string());
                         }
 
                         // And messaging related tracking...
@@ -294,7 +294,7 @@ fn inspect_log_files(args: &CmdArgs) -> Result<BTreeMap<String, Vec<String>>> {
 
     let mut report = BTreeMap::<String, Vec<String>>::new();
 
-    let info = update_commands_info_for_markers(&args.logs_path, args.nodes)?;
+    let info = update_cmds_info_for_markers(&args.logs_path, args.nodes)?;
 
     println!("-------------------------");
     println!("LogMarker Stats: (markers found across all log files): ");
@@ -306,29 +306,29 @@ fn inspect_log_files(args: &CmdArgs) -> Result<BTreeMap<String, Vec<String>>> {
     let default_map = BTreeMap::default();
     let spawned = info
         .by_marker
-        .get(&LogMarker::CommandHandleSpawned)
+        .get(&LogMarker::CmdHandlingSpawned)
         .unwrap_or(&default_map);
 
     let started = info
         .by_marker
-        .get(&LogMarker::CommandHandleStart)
+        .get(&LogMarker::CmdProcessStart)
         .unwrap_or(&default_map);
     let succeeded = info
         .by_marker
-        .get(&LogMarker::CommandHandleEnd)
+        .get(&LogMarker::CmdProcessEnd)
         .unwrap_or(&default_map);
     let failed = info
         .by_marker
-        .get(&LogMarker::CommandHandleError)
+        .get(&LogMarker::CmdProcessingError)
         .unwrap_or(&default_map);
 
     if let Some(cmd) = &args.cmd {
         match cmd {
-            SubCommands::Commands { ref cmd_id } => {
-                populate_commands_tree(spawned, started, succeeded, failed, &mut report, cmd_id);
+            SubCmds::Cmds { ref cmd_id } => {
+                populate_cmds_tree(spawned, started, succeeded, failed, &mut report, cmd_id);
             }
-            SubCommands::Messages { ref msg_id } => {
-                populate_commands_tree_for_msgs(
+            SubCmds::Msgs { ref msg_id } => {
+                populate_cmds_tree_for_msgs(
                     &info,
                     spawned,
                     started,
@@ -338,7 +338,7 @@ fn inspect_log_files(args: &CmdArgs) -> Result<BTreeMap<String, Vec<String>>> {
                     msg_id,
                 );
             }
-            SubCommands::IncompleteCmds => {
+            SubCmds::IncompleteCmds => {
                 check_completed_cmds(&info, spawned, started, succeeded, failed, &mut report);
             }
         }
@@ -353,17 +353,17 @@ fn inspect_log_files(args: &CmdArgs) -> Result<BTreeMap<String, Vec<String>>> {
             println!("** Has been an elder **");
         }
         println!();
-        if let Some(commands) = markers.get(&LogMarker::CommandHandleSpawned) {
-            println!("Spawned commands: {:?}", commands.len());
+        if let Some(cmds) = markers.get(&LogMarker::CmdHandlingSpawned) {
+            println!("Spawned cmds: {:?}", cmds.len());
         }
-        if let Some(commands) = markers.get(&LogMarker::CommandHandleStart) {
-            println!("Started commands: {:?}", commands.len());
+        if let Some(cmds) = markers.get(&LogMarker::CmdProcessStart) {
+            println!("Started cmds: {:?}", cmds.len());
         }
-        if let Some(commands) = markers.get(&LogMarker::CommandHandleEnd) {
-            println!("Succeeded commands: {:?}", commands.len());
+        if let Some(cmds) = markers.get(&LogMarker::CmdProcessEnd) {
+            println!("Succeeded cmds: {:?}", cmds.len());
         }
-        if let Some(commands) = markers.get(&LogMarker::CommandHandleError) {
-            println!("Errored commands: {:?}", commands.len());
+        if let Some(cmds) = markers.get(&LogMarker::CmdProcessingError) {
+            println!("Errored cmds: {:?}", cmds.len());
         }
 
         if let Some(msgs) = info.msgs_per_node.get(&node_name) {
@@ -376,30 +376,30 @@ fn inspect_log_files(args: &CmdArgs) -> Result<BTreeMap<String, Vec<String>>> {
     Ok(report)
 }
 
-// Try to find inconsistencies among the commands,
+// Try to find inconsistencies among the cmds,
 // trying to find those which were started but not completed
 fn check_completed_cmds(
     info: &ScannedInfo,
-    spawned: &CommandsInfoList,
-    started: &CommandsInfoList,
-    succeeded: &CommandsInfoList,
-    failed: &CommandsInfoList,
+    spawned: &CmdsInfoList,
+    started: &CmdsInfoList,
+    succeeded: &CmdsInfoList,
+    failed: &CmdsInfoList,
     report: &mut BTreeMap<String, Vec<String>>,
 ) {
     let mut cmds_with_error = vec![];
     let mut cmds_not_completed = vec![];
     let mut cmds_with_end = 0;
 
-    println!("Checking completed commands...");
+    println!("Checking completed cmds...");
     println!("-------------------------");
 
-    for (cmd_id, log_entry, logfile) in spawned.iter().flat_map(|(_, subcommands)| {
-        let mut commands = vec![];
-        for (cmd_id, log_entry) in subcommands.cmds_logs.iter() {
-            commands.push((cmd_id, log_entry, subcommands.logfile.clone()))
+    for (cmd_id, log_entry, logfile) in spawned.iter().flat_map(|(_, sub_cmds)| {
+        let mut cmds = vec![];
+        for (cmd_id, log_entry) in sub_cmds.cmd_logs.iter() {
+            cmds.push((cmd_id, log_entry, sub_cmds.logfile.clone()))
         }
 
-        commands
+        cmds
     }) {
         let logfile = logfile.display().to_string();
 
@@ -407,11 +407,11 @@ fn check_completed_cmds(
 
         if started
             .get(&root_cmd_id)
-            .and_then(|subcmds| subcmds.cmds_logs.get(cmd_id))
+            .and_then(|sub_cmds| sub_cmds.cmd_logs.get(cmd_id))
             .is_none()
         {
             println!(
-                "Command with id {} spawned but not started: {}",
+                "Cmd with id {} spawned but not started: {}",
                 cmd_id, log_entry
             );
 
@@ -421,21 +421,21 @@ fn check_completed_cmds(
                 .or_insert_with(Vec::new)
                 .push(log_entry.clone());
         } else {
-            // Command spwned and started, let's see if it completed...
+            // cmd spawned and started, let's see if it completed...
             if succeeded
                 .get(&root_cmd_id)
-                .and_then(|subcmds| subcmds.cmds_logs.get(cmd_id))
+                .and_then(|sub_cmds| sub_cmds.cmd_logs.get(cmd_id))
                 .is_none()
             {
                 if failed
                     .get(&root_cmd_id)
-                    .and_then(|subcmds| subcmds.cmds_logs.get(cmd_id))
+                    .and_then(|sub_cmds| sub_cmds.cmd_logs.get(cmd_id))
                     .is_none()
                 {
                     cmds_with_error.push((cmd_id, logfile, log_entry));
                 } else {
                     println!(
-                        "Command with id {} spawned and started, but not completed: {}",
+                        "Cmd with id {} spawned and started, but not completed: {}",
                         cmd_id, log_entry
                     );
                     cmds_not_completed.push((cmd_id, logfile.clone(), log_entry));
@@ -445,22 +445,22 @@ fn check_completed_cmds(
                         .push(log_entry.clone());
                 }
             } else {
-                // command completed
+                // cmd completed
                 cmds_with_end += 1;
             }
         }
     }
 
     println!(
-        "Commands handled which Failed: {}, Succeeded: {}, not Completed: {}",
+        "Cmds handled which Failed: {}, Succeeded: {}, not Completed: {}",
         cmds_with_error.len(),
         cmds_with_end,
         cmds_not_completed.len()
     );
-    println!("Incoming messages handled: {}", info.cmd_by_msg_id.len());
+    println!("Incoming msgs handled: {}", info.cmd_by_msg_id.len());
 
     if !cmds_not_completed.is_empty() {
-        println!("\n!!! ERROR !!!: Some command/s were not completed in log:");
+        println!("\n!!! ERROR !!!: Some cmd/s were not completed in log:");
         for (id, file, line) in cmds_not_completed {
             println!("{}{}{}", id, file, line);
         }
@@ -468,7 +468,7 @@ fn check_completed_cmds(
     println!();
 
     if !cmds_with_error.is_empty() {
-        println!("\n!!! ERROR !!!: Some commands produced errors:");
+        println!("\n!!! ERROR !!!: Some cmds produced errors:");
         for (id, file, line) in cmds_with_error {
             println!("{} {} {}", id, file, line);
         }
@@ -477,16 +477,16 @@ fn check_completed_cmds(
     println!("-------------------------");
 }
 
-// Populate the report with the list of commands/sub-commands correlated to the provided cmd id.
-fn populate_commands_tree(
-    spawned: &CommandsInfoList,
-    started: &CommandsInfoList,
-    succeeded: &CommandsInfoList,
-    failed: &CommandsInfoList,
+// Populate the report with the list of cmds/sub-cmds correlated to the provided cmd id.
+fn populate_cmds_tree(
+    spawned: &CmdsInfoList,
+    started: &CmdsInfoList,
+    succeeded: &CmdsInfoList,
+    failed: &CmdsInfoList,
     report: &mut BTreeMap<String, Vec<String>>,
     cmd_id: &str,
 ) {
-    println!("Looking for commands spawned from cmd id {}", cmd_id);
+    println!("Looking for cmds spawned from cmd id {}", cmd_id);
     let root_cmd_id = get_root_cmd_id(cmd_id);
 
     populate_tree_for(spawned, &root_cmd_id, report);
@@ -496,13 +496,13 @@ fn populate_commands_tree(
 }
 
 fn populate_tree_for(
-    command_list: &CommandsInfoList,
+    cmd_list: &CmdsInfoList,
     root_cmd_id: &str,
     report: &mut BTreeMap<String, Vec<String>>,
 ) {
-    if let Some(matching_cmds) = command_list.get(root_cmd_id) {
+    if let Some(matching_cmds) = cmd_list.get(root_cmd_id) {
         matching_cmds
-            .cmds_logs
+            .cmd_logs
             .iter()
             .for_each(|(cmd_id, log_entry)| {
                 report
@@ -517,26 +517,26 @@ fn populate_tree_for(
     }
 }
 
-// Populate the report with the list of message ids and their correlated commands.
-fn populate_commands_tree_for_msgs(
+// Populate the report with the list of message ids and their correlated cmds.
+fn populate_cmds_tree_for_msgs(
     info: &ScannedInfo,
-    spawned: &CommandsInfoList,
-    started: &CommandsInfoList,
-    succeeded: &CommandsInfoList,
-    failed: &CommandsInfoList,
+    spawned: &CmdsInfoList,
+    started: &CmdsInfoList,
+    succeeded: &CmdsInfoList,
+    failed: &CmdsInfoList,
     report: &mut BTreeMap<String, Vec<String>>,
     msg_id: &str,
 ) {
-    println!("Looking for commands spawned from msg id {}", msg_id);
+    println!("Looking for cmds spawned from msg id {}", msg_id);
 
     if let Some(ids) = info.cmd_by_msg_id.get(msg_id) {
         ids.iter().for_each(|root_cmd_id| {
-            populate_commands_tree(spawned, started, succeeded, failed, report, root_cmd_id);
+            populate_cmds_tree(spawned, started, succeeded, failed, report, root_cmd_id);
         });
     }
 }
 
-// Given a command id, return the root id, e.g. the root cmd id of 'abc.1.0.2' is 'a.b.c'.
+// Given a cmd id, return the root id, e.g. the root cmd id of 'abc.1.0.2' is 'a.b.c'.
 fn get_root_cmd_id(cmd_id: &str) -> CmdId {
     let mut root_cmd_id = cmd_id.to_string();
     root_cmd_id.truncate(cmd_id.find('.').unwrap_or_else(|| cmd_id.len()));
