@@ -10,12 +10,9 @@ mod listeners;
 mod messaging;
 use crate::messaging::{
     data::{CmdError, OperationId, QueryResponse},
-    MessageId,
+    MsgId,
 };
-use crate::peer::Peer;
 use crate::prefix_map::NetworkPrefixMap;
-use bls::PublicKey as BlsPublicKey;
-use bytes::Bytes;
 use dashmap::DashMap;
 use qp2p::Endpoint;
 use std::sync::Arc;
@@ -24,12 +21,11 @@ use tokio::time::Duration;
 use xor_name::XorName;
 
 // Here we dont track the msg_id across the network, but just use it as a local identifier to remove the correct listener
-type PendingQueryResponses = Arc<DashMap<OperationId, Vec<(MessageId, QueryResponseSender)>>>;
-use uluru::LRUCache;
+type PendingQueryResponses = Arc<DashMap<OperationId, Vec<(MsgId, QueryResponseSender)>>>;
 type QueryResponseSender = Sender<QueryResponse>;
 
 type CmdResponse = (std::net::SocketAddr, Option<CmdError>);
-type PendingCmdAcks = Arc<DashMap<MessageId, Sender<CmdResponse>>>;
+type PendingCmdAcks = Arc<DashMap<MsgId, Sender<CmdResponse>>>;
 
 #[derive(Debug)]
 pub struct QueryResult {
@@ -37,8 +33,6 @@ pub struct QueryResult {
     pub operation_id: OperationId,
 }
 
-pub(crate) type AeCache = LRUCache<(Vec<Peer>, BlsPublicKey, Bytes), 100>;
-
 #[derive(Clone, Debug)]
 pub(super) struct Session {
     // Session endpoint.
@@ -52,16 +46,12 @@ pub(super) struct Session {
     pending_cmds: PendingCmdAcks,
     /// All elders we know about from AE messages
     network: Arc<NetworkPrefixMap>,
-    /// AE redirect cache
-    ae_redirect_cache: Arc<RwLock<AeCache>>,
-    // AE retry cache
-    ae_retry_cache: Arc<RwLock<AeCache>>,
     /// Network's genesis key
     genesis_key: bls::PublicKey,
-    /// Initial network comms messageId
-    initial_connection_check_msg_id: Arc<RwLock<Option<MessageId>>>,
+    /// Initial network comms MsgId
+    initial_connection_check_msg_id: Arc<RwLock<Option<MsgId>>>,
     /// Standard time to await potential AE messages:
-    standard_wait: Duration,
+    cmd_ack_wait: Duration,
     /// Closed connection tracking, used to validate if a new connection is needed or not. Xorname to ConnectionId
     elder_last_closed_connections: Arc<DashMap<XorName, Vec<usize>>>,
 }
