@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::node::{
-    api::command::Command,
+    api::cmds::Cmd,
     core::{Core, Proposal},
     Result,
 };
@@ -15,7 +15,7 @@ use std::{collections::BTreeSet, iter, net::SocketAddr};
 use xor_name::XorName;
 
 impl Core {
-    pub(crate) async fn handle_peer_lost(&self, addr: &SocketAddr) -> Result<Vec<Command>> {
+    pub(crate) async fn handle_peer_lost(&self, addr: &SocketAddr) -> Result<Vec<Cmd>> {
         let name = if let Some(peer) = self.network_knowledge.find_member_by_addr(addr).await {
             debug!("Lost known peer {}", peer);
             peer.name()
@@ -29,12 +29,12 @@ impl Core {
             return Ok(vec![]);
         }
 
-        let mut commands = self.propose_offline(name).await?;
-        commands.push(Command::StartConnectivityTest(name));
-        Ok(commands)
+        let mut cmds = self.propose_offline(name).await?;
+        cmds.push(Cmd::StartConnectivityTest(name));
+        Ok(cmds)
     }
 
-    pub(crate) async fn propose_offline(&self, name: XorName) -> Result<Vec<Command>> {
+    pub(crate) async fn propose_offline(&self, name: XorName) -> Result<Vec<Cmd>> {
         self.cast_offline_proposals(&iter::once(name).collect())
             .await
     }
@@ -42,7 +42,7 @@ impl Core {
     pub(crate) async fn cast_offline_proposals(
         &self,
         names: &BTreeSet<XorName>,
-    ) -> Result<Vec<Command>> {
+    ) -> Result<Vec<Cmd>> {
         // Don't send the `Offline` proposal to the peer being lost as that send would fail,
         // triggering a chain of further `Offline` proposals.
         let elders: Vec<_> = self
@@ -53,15 +53,15 @@ impl Core {
             .filter(|peer| !names.contains(&peer.name()))
             .cloned()
             .collect();
-        let mut result: Vec<Command> = Vec::new();
+        let mut result: Vec<Cmd> = Vec::new();
         for name in names.iter() {
             if let Some(info) = self.network_knowledge.get_section_member(name).await {
                 let info = info.leave()?;
-                if let Ok(commands) = self
+                if let Ok(cmds) = self
                     .send_proposal(elders.clone(), Proposal::Offline(info))
                     .await
                 {
-                    result.extend(commands);
+                    result.extend(cmds);
                 }
             }
         }
