@@ -34,7 +34,7 @@ pub(crate) use relocation::{check as relocation_check, ChurnId};
 use self::{data_storage::DataStorage, split_barrier::SplitBarrier};
 
 use super::{
-    api::command::Command,
+    api::cmds::Cmd,
     dkg::DkgVoter,
     network_knowledge::{NetworkKnowledge, SectionKeyShare, SectionKeysProvider},
     node_info::Node,
@@ -74,7 +74,7 @@ pub(super) const RESOURCE_PROOF_DIFFICULTY: u8 = 10;
 const BACKOFF_CACHE_LIMIT: usize = 100;
 pub(crate) const CONCURRENT_JOINS: usize = 7;
 
-// How long to hold on to correlated `Peer`s for chunk queries. Since chunk queries are forwarded
+// How long to hold on to correlated `Peer`s for data queries. Since data queries are forwarded
 // from elders (with whom the client is connected) to adults (who hold the data), the elder handling
 // the query cannot reply immediately. For now, they stash a reference to the client `Peer` in
 // `Core::pending_data_queries`, which is a cache with duration-based expiry.
@@ -82,7 +82,12 @@ pub(crate) const CONCURRENT_JOINS: usize = 7;
 // `crate::client::SN_CLIENT_QUERY_TIMEOUT`), but the timeout is configurable. Ideally this would be
 // based on liveness properties (e.g. the timeout should be dynamic based on the responsiveness of
 // the section).
-const CHUNK_QUERY_TIMEOUT: Duration = Duration::from_secs(60 * 5 /* 5 mins */);
+const DATA_QUERY_TIMEOUT: Duration = Duration::from_secs(60 * 5 /* 5 mins */);
+
+// This prevents pending query limit unbound growth
+pub(crate) const DATA_QUERY_LIMIT: usize = 100;
+// per query we can have this many peers, so the total peers waiting can be QUERY_LIMIT * MAX_WAITING_PEERS_PER_QUERY
+pub(crate) const MAX_WAITING_PEERS_PER_QUERY: usize = 25;
 
 // Store up to 100 in use backoffs
 pub(crate) type AeBackoffCache =
@@ -114,7 +119,7 @@ pub(crate) struct Core {
     pub(super) data_storage: DataStorage,
     capacity: Capacity,
     liveness: Liveness,
-    pending_data_queries: Arc<Cache<OperationId, Peer>>,
+    pending_data_queries: Arc<Cache<OperationId, Vec<Peer>>>,
     ae_backoff_cache: AeBackoffCache,
 }
 
@@ -137,7 +142,6 @@ impl Core {
 
         let data_storage = DataStorage::new(&root_storage_dir, used_space.clone())?;
 
-        let capacity = Capacity::new(BTreeMap::new());
         info!("Creating Liveness checks");
         let adult_liveness = Liveness::new(
             network_knowledge
@@ -165,9 +169,9 @@ impl Core {
             current_joins_semaphore: Arc::new(Semaphore::new(CONCURRENT_JOINS)),
             resource_proof: ResourceProof::new(RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY),
             data_storage,
-            capacity,
+            capacity: Capacity::default(),
             liveness: adult_liveness,
-            pending_data_queries: Arc::new(Cache::with_expiry_duration(CHUNK_QUERY_TIMEOUT)),
+            pending_data_queries: Arc::new(Cache::with_expiry_duration(DATA_QUERY_TIMEOUT)),
             ae_backoff_cache: AeBackoffCache::default(),
         })
     }
@@ -185,7 +189,7 @@ impl Core {
         }
     }
 
-    pub(crate) async fn generate_probe_message(&self) -> Result<Command> {
+    pub(crate) async fn generate_probe_msg(&self) -> Result<Cmd> {
         // Generate a random address not belonging to our Prefix
         let mut dst = XorName::random();
 
@@ -202,12 +206,12 @@ impl Core {
         let recipients = matching_section.elders_vec();
 
         info!(
-            "ProbeMessage target {:?} w/key {:?}",
+            "ProbeMsg target {:?} w/key {:?}",
             matching_section.prefix(),
             section_key
         );
 
-        self.send_direct_message_to_nodes_in_section(recipients, message, dst_name, section_key)
+        self.send_direct_msg_to_nodes(recipients, message, dst_name, section_key)
             .await
     }
 
@@ -225,12 +229,12 @@ impl Core {
         });
     }
 
-    /// Generate commands and fire events based upon any node state changes.
+    /// Generate cmds and fire events based upon any node state changes.
     pub(crate) async fn update_self_for_new_node_state(
         &self,
         old: StateSnapshot,
-    ) -> Result<Vec<Command>> {
-        let mut commands = vec![];
+    ) -> Result<Vec<Cmd>> {
+        let mut cmds = vec![];
         let new = self.state_snapshot().await;
 
         if new.section_key != old.section_key {
@@ -244,11 +248,11 @@ impl Core {
                 );
 
                 if !self.section_keys_provider.is_empty().await {
-                    commands.extend(self.promote_and_demote_elders().await?);
+                    cmds.extend(self.promote_and_demote_elders().await?);
 
                     // Whenever there is an elders change, casting a round of joins_allowed
                     // proposals to sync.
-                    commands.extend(
+                    cmds.extend(
                         self.propose(Proposal::JoinsAllowed(*self.joins_allowed.read().await))
                             .await?,
                     );
@@ -258,7 +262,7 @@ impl Core {
             }
 
             if new.is_elder || old.is_elder {
-                commands.extend(self.send_ae_update_to_our_section().await);
+                cmds.extend(self.send_ae_update_to_our_section().await);
             }
 
             let current: BTreeSet<_> = self.network_knowledge.authority_provider().await.names();
@@ -296,7 +300,7 @@ impl Core {
                     info!("{}: {:?}", LogMarker::StillElderAfterSplit, new.prefix);
                 }
 
-                commands.extend(self.send_updates_to_sibling_section(&old).await?);
+                cmds.extend(self.send_updates_to_sibling_section(&old).await?);
                 self.liveness_retain_only(
                     self.network_knowledge
                         .adults()
@@ -312,13 +316,13 @@ impl Core {
                     self_status_change,
                 }
             } else {
-                commands.extend(
-                    self.send_metadata_updates_to(
-                        self.network_knowledge.prefix().await,
+                cmds.extend(
+                    self.send_metadata_updates_to_nodes(
                         self.network_knowledge
                             .authority_provider()
                             .await
                             .elders_vec(),
+                        &self.network_knowledge.prefix().await,
                         new.section_key,
                     )
                     .await?,
@@ -330,9 +334,8 @@ impl Core {
                 }
             };
 
-            commands.extend(
-                self.send_metadata_updates_to(
-                    self.network_knowledge.prefix().await,
+            cmds.extend(
+                self.send_metadata_updates_to_nodes(
                     self.network_knowledge
                         .authority_provider()
                         .await
@@ -340,6 +343,7 @@ impl Core {
                         .filter(|peer| !old.elders.contains(&peer.name()))
                         .cloned()
                         .collect(),
+                    &self.network_knowledge.prefix().await,
                     new.section_key,
                 )
                 .await?,
@@ -348,7 +352,7 @@ impl Core {
             self.send_event(event).await
         }
 
-        Ok(commands)
+        Ok(cmds)
     }
 
     pub(crate) async fn section_key_by_name(&self, name: &XorName) -> bls::PublicKey {
