@@ -28,7 +28,7 @@ pub use address::{
 };
 pub use cache::Cache;
 pub use chunk::{Chunk, MAX_CHUNK_SIZE_IN_BYTES};
-pub use errors::{convert_dt_error_to_error_message, Error, Result};
+pub use errors::{convert_dt_error_to_error_msg, Error, Result};
 pub use keys::{
     keypair::{BlsKeypairShare, Encryption, Keypair, OwnerType, Signing},
     node_keypairs::NodeKeypairs,
